import ts from 'typescript';
import type { Transformer, Options } from '../types';
export declare function loadTsconfig(compilerOptionsJSON: any, filename: string, tsOptions: Options.Typescript): {
    errors: never[];
    options: any;
} | {
    errors: ts.Diagnostic[];
    options: ts.CompilerOptions;
};
declare const transformer: Transformer<Options.Typescript>;
export { transformer };
