import ConstTag from '../../../nodes/ConstTag';
import Block from '../../Block';
import Renderer from '../../Renderer';
export declare function add_const_tags(block: Block, const_tags: ConstTag[], ctx: string): any[];
export declare function add_const_tags_context(renderer: Renderer, const_tags: ConstTag[]): void;
