import Renderer, { RenderOptions } from '../Renderer';
import InlineComponent from '../../nodes/InlineComponent';
export default function (node: InlineComponent, renderer: Renderer, options: RenderOptions): void;
