import type { PreprocessorGroup, Options } from '../types';
/** Adapted from https://github.com/TehShrike/svelte-preprocess-postcss */
declare const _default: (options?: Options.Postcss) => PreprocessorGroup;
export default _default;
