"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.throwTypescriptError = exports.throwError = void 0;
const throwError = (msg) => {
    throw new Error(`[svelte-preprocess] ${msg}`);
};
exports.throwError = throwError;
const throwTypescriptError = () => {
    (0, exports.throwError)(`Encountered type error`);
};
exports.throwTypescriptError = throwTypescriptError;
