export declare const foreign = "https://svelte.dev/docs#template-syntax-svelte-options";
export declare const html = "http://www.w3.org/1999/xhtml";
export declare const mathml = "http://www.w3.org/1998/Math/MathML";
export declare const svg = "http://www.w3.org/2000/svg";
export declare const xlink = "http://www.w3.org/1999/xlink";
export declare const xml = "http://www.w3.org/XML/1998/namespace";
export declare const xmlns = "http://www.w3.org/2000/xmlns";
export declare const valid_namespaces: string[];
export declare const namespaces: {
    readonly foreign: "https://svelte.dev/docs#template-syntax-svelte-options";
    readonly html: "http://www.w3.org/1999/xhtml";
    readonly mathml: "http://www.w3.org/1998/Math/MathML";
    readonly svg: "http://www.w3.org/2000/svg";
    readonly xlink: "http://www.w3.org/1999/xlink";
    readonly xml: "http://www.w3.org/XML/1998/namespace";
    readonly xmlns: "http://www.w3.org/2000/xmlns";
};
