import AttributeWrapper from './Attribute';
import BindingWrapper from './Binding';
export default function handle_select_value_binding(attr: AttributeWrapper | BindingWrapper, dependencies: Set<string>): void;
