export { onDestroy, setContext, getContext, getAllContexts, hasContext, tick, createEventDispatcher, SvelteComponent, SvelteComponentTyped } from './index';
export declare function onMount(): void;
export declare function beforeUpdate(): void;
export declare function afterUpdate(): void;
