export { SvelteComponentDev as SvelteComponent, SvelteComponentTyped, createEventDispatcher, getAllContexts, getContext, hasContext, onDestroy, setContext, tick } from './internal/index.mjs';

function onMount() { }
function beforeUpdate() { }
function afterUpdate() { }

export { afterUpdate, beforeUpdate, onMount };
