"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.blubb = void 0;
function blubb() {
    return true;
}
exports.blubb = blubb;
//# sourceMappingURL=definitions.js.map