export declare const name = "Comparison";
export declare const structure: {
    value: StringConstructor;
};
export declare function parse(): {
    type: string;
    loc: any;
    value: any;
};
export declare function generate(node: any): void;
