import type { PreprocessorArgs } from '../types';
export declare const getTagInfo: ({ attributes, filename, content, markup, }: PreprocessorArgs) => Promise<{
    filename: string | undefined;
    attributes: Record<string, string | boolean>;
    content: string;
    lang: string | null | undefined;
    alias: string | null;
    dependencies: string[];
    markup: string;
}>;
