import type { Transformer, Options } from '../types';
/** Adapted from https://github.com/TehShrike/svelte-preprocess-postcss */
declare const transformer: Transformer<Options.Postcss>;
export { transformer };
