export declare function is_bracket_open(code: any): boolean;
export declare function is_bracket_close(code: any): boolean;
export declare function is_bracket_pair(open: any, close: any): boolean;
export declare function get_bracket_close(open: any): number;
