import Attribute from '../../../nodes/Attribute';
import { Expression as ESTreeExpression } from 'estree';
export declare function get_class_attribute_value(attribute: Attribute): ESTreeExpression;
export declare function get_attribute_value(attribute: Attribute): ESTreeExpression;
export declare function get_attribute_expression(attribute: Attribute): ESTreeExpression;
